@@ -25,7 +25,13 @@ if PYQT_VERSIONS == "PyQt5":
         QMainWindow,
         QDesktopWidget,
         QGraphicsDropShadowEffect,
-        QSlider
+        QSlider,
+        QListWidget,
+        QListWidgetItem,
+        QListView,
+        QAction,
+        QAbstractScrollArea,
+        QRadioButton
     )
 
 if PYQT_VERSIONS == "PyQt6":
@@ -54,7 +60,13 @@ if PYQT_VERSIONS == "PyQt6":
         QMainWindow,
         QDesktopWidget,
         QGraphicsDropShadowEffect,
-        QSlider
+        QSlider,
+        QListWidget,
+        QListWidgetItem,
+        QListView,
+        QAction,
+        QAbstractScrollArea,
+        QRadioButton
 )
 
 if PYQT_VERSIONS == "PySide2":
@@ -83,7 +95,13 @@ if PYQT_VERSIONS == "PySide2":
         QMainWindow,
         QDesktopWidget,
         QGraphicsDropShadowEffect,
-        QSlider
+        QSlider,
+        QListWidget,
+        QListWidgetItem,
+        QListView,
+        QAction,
+        QAbstractScrollArea,
+        QRadioButton
     )
 
 if PYQT_VERSIONS == "PySide6":
@@ -112,5 +130,11 @@ if PYQT_VERSIONS == "PySide6":
         QMainWindow,
         QDesktopWidget,
         QGraphicsDropShadowEffect,
-        QSlider
+        QSlider,
+        QListWidget,
+        QListWidgetItem,
+        QListView,
+        QAction,
+        QAbstractScrollArea,
+        QRadioButton
     )
\ No newline at end of file
